@@ -123,6 +123,8 @@ def field(context, field, widget=None, **kwargs):
     field_data = {
         'form_field': field,
         'id': field.auto_id,
+        'widget_type': field.field.widget.__class__.__name__,
+        'field_type': field.field.__class__.__name__,
     }
 
     for attr in ('css_classes', 'errors', 'field', 'form', 'help_text',
@@ -131,28 +133,38 @@ def field(context, field, widget=None, **kwargs):
 
     for attr in ('choices', 'widget', 'required'):
         field_data[attr] = getattr(field.field, attr, None)
-        if attr == 'choices' and field_data[attr]:
-            field_data[attr] = [
-                (force_text(k), v)
-                for k, v in field_data[attr]
-            ]
-            # Normalize the value [django.forms.widgets.Select.render_options]
-            field_data['value'] = force_text(field_data['value']())
+
+    if field_data['choices']:
+        field_data['display'] = dict(field.field.choices).get(field.value, '')
+        field_data['choices'] = [
+            (force_text(k), v)
+            for k, v in field_data['choices']
+        ]
+        # Normalize the value [django.forms.widgets.Select.render_options]
+        value = field_data['value']()
+        field_data['value'] = ([force_text(v) for v in value]
+                              if isinstance(value, (list, tuple))
+                              else force_text(value))
 
     # Allow supplied values to override field data
     field_data.update(kwargs)
 
     if widget is None:
-        for name in auto_widget(field):
-            block = context['formulation'].get_block(name)
-            if block is not None:
-                break
+        widgets = auto_widget(field)
     else:
-        block = context['formulation'].get_block(widget)
+        widgets = [widget]
+    for name in widgets:
+        block = context['formulation'].get_block(name)
+        if block is not None:
+            break
 
     if block is None:
         raise template.TemplateSyntaxError(
-            "No widget for field: %s (%r)" % (field.name, field.field)
+            "No widget for field: %s (%r) [Tried: %s]" % (
+                field.name,
+                field.field,
+                widgets
+            )
         )
 
     field_data['block'] = block
